import 'dart:io';

import 'package:contacts_service/contacts_service.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:share_apps/model/user_bean.dart';
import 'package:share_apps/screens/home_screen.dart';
import 'package:share_apps/utils/common_utils.dart';
import 'package:share_apps/utils/string_utils.dart';
import 'package:share_apps/widgets/widgets_importer.dart';

import 'invite_contact_screen.dart';

class ContactSelection extends StatefulWidget {
  ContactSelection(this.bean);

  final UserBean bean;

  @override
  _ContactSelectionState createState() => new _ContactSelectionState();
}

class _ContactSelectionState extends State<ContactSelection> {
  List<Contact> _contacts = new List<Contact>();
  List<CustomContact> _uiCustomContacts = List<CustomContact>();
  List<CustomContact> _allContacts = List<CustomContact>();
  List<CustomContact> _filterdContacts = List<CustomContact>();
  bool _isLoading = false;

  @override
  void initState() {
    super.initState();
    refreshContacts();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: !_isLoading
          ? Column(
              children: <Widget>[
                InkWell(
                  onTap: () {
                    Navigator.pushReplacement(
                        context,
                        MaterialPageRoute(
                            builder: (context) => HomeScreen(
                                  widget.bean,
                                )));
                  },
                  child: Padding(
                    padding: const EdgeInsets.only(top: 40,bottom: 10),
                    child: AddText(StringUtils.CANCEL, Colors.red, 20,
                        FontWeight.normal, false),
                  ),
                ),
                Row(
                  children: <Widget>[
                    AddTopButton(true),
                    AddTopButton(false),
                  ],
                ),
                Center(
                  child: Padding(
                    padding: const EdgeInsets.all(10.0),
                    child: new TextField(
                      textAlign: TextAlign.center,
                      decoration: new InputDecoration(
                          hintText: StringUtils.SEARCH_NUMBER_HINT,
                          border: InputBorder.none),
                      onChanged: onSearchTextChanged,
                    ),
                  ),
                ),
                Expanded(
                  child: ListView.builder(
                    itemCount: _filterdContacts?.length,
                    itemBuilder: (BuildContext context, int index) {
                      CustomContact _contact = _filterdContacts[index];
                      var _phonesList = _contact.contact.phones.toList();
                      return _buildListTile(_contact, _phonesList);
                    },
                  ),
                ),
              ],
            )
          : Container(
              color: Colors.white,
              child: Column(
                children: [
                  Expanded(
                    flex: 1,
                    child: Align(
                      alignment: Alignment.bottomCenter,
                      child: InkWell(
                        onTap: () async {},
                        child: Image.asset(
                          StringUtils.IC_LOGO,
                          width: 50,
                          height: 50,
                        ),
                      ),
                    ),
                  ),
                  AddSizeBox(100, 0),
                  Expanded(
                    flex: 1,
                    child: Container(
                      child: Text(
                        StringUtils.CONTACT_SELECTION_WAIT_MESSAGE,
                        textAlign: TextAlign.center,
                        style: TextStyle(
                            decoration: TextDecoration.none,
                            fontSize: 15,
                            color: Colors.black),
                      ),
                    ),
                  ),
                ],
              ),
            ),
    );
  }

  void selectAll() {
    for (int i = 0; i < _filterdContacts.length; i++) {
      _filterdContacts[i].isChecked = true;
    }
  }

  onSearchTextChanged(String text) async {
    setState(() {
      _filterdContacts.clear();
      if (text.isEmpty) {
        _filterdContacts.addAll(_allContacts);
      } else
        _allContacts.forEach((userDetail) {
          var _phonesList = userDetail.contact.phones.toList();
          if (userDetail.contact.displayName
                  .toLowerCase()
                  .contains(text.toLowerCase()) ||
              (_phonesList.length > 0
                  ? _phonesList[0]
                      .value
                      .toLowerCase()
                      .contains(text.toLowerCase())
                  : false)) _filterdContacts.add(userDetail);
        });
    });
  }

  ListTile _buildListTile(CustomContact c, List<Item> list) {
    return ListTile(
      title: Text(c.contact.displayName ?? ""),
      subtitle: list.length >= 1 && list[0]?.value != null
          ? Text(list[0].value)
          : Text(''),
      trailing: Checkbox(
          activeColor: Colors.green,
          value: c.isChecked,
          onChanged: (bool value) {
            setState(() {
              c.isChecked = value;
            });
          }),
    );
  }

  refreshContacts() async {
    setState(() {
      _isLoading = true;
    });
    var contacts = await ContactsService.getContacts();
    _populateContacts(contacts);
  }

  void _populateContacts(Iterable<Contact> contacts) {
    _contacts = contacts.where((item) => item.displayName != null).toList();
    _contacts.sort((a, b) => a.displayName.compareTo(b.displayName));
    _allContacts =
        _contacts.map((contact) => CustomContact(contact: contact)).toList();
    setState(() {
      _uiCustomContacts.addAll(_allContacts);
      _filterdContacts.addAll(_allContacts);
      _isLoading = false;
    });
  }

  Widget AddTopButton(bool isSelectAll) {
    return Expanded(
      child: Align(
        alignment: isSelectAll ? Alignment.centerLeft : Alignment.centerRight,
        child: InkWell(
          onTap: () {
            if (isSelectAll) {
              setState(() {
                selectAll();
              });
            } else {
              proceed();
            }
          },
          child: Padding(
            padding: const EdgeInsets.all(15.0),
            child: AddText(
                isSelectAll ? StringUtils.SELECT_ALL : StringUtils.PROCEED_,
                isSelectAll ? Colors.black : Colors.green,
                18,
                FontWeight.normal,
                false),
          ),
        ),
      ),
    );
  }

  Future<void> proceed() async {
    try {
      final result = await InternetAddress.lookup('google.com');
      if (result.isNotEmpty && result[0].rawAddress.isNotEmpty) {
        _uiCustomContacts = _filterdContacts
            .where((contact) => contact.isChecked == true)
            .toList();
        if (_uiCustomContacts != null && _uiCustomContacts.length > 0)
          Navigator.pushReplacement(
              context,
              MaterialPageRoute(
                  builder: (context) =>
                      InviteContact(_uiCustomContacts, widget.bean)));
        else
          CommonUtils.showToast("Please Select Contact", Colors.black);
      }
    } on SocketException catch (_) {
      CommonUtils.showToast(StringUtils.CHECK_NETWORK, Colors.red);
    }
  }
}

class CustomContact {
  final Contact contact;
  bool isChecked;

  CustomContact({
    this.contact,
    this.isChecked = false,
  });
}
