import 'dart:convert';
import 'dart:ui';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter/widgets.dart';
import 'package:permission_handler/permission_handler.dart';
import 'package:share_apps/model/user_bean.dart';
import 'package:share_apps/screens/contact_selection.dart';
import 'package:share_apps/utils/common_utils.dart';
import 'package:share_apps/utils/string_utils.dart';
import 'package:share_apps/widgets/widgets_importer.dart';

import 'email_invitation_loading_screen.dart';

bool isLoading = false;
UserBean userBean;

class HomeScreen extends StatefulWidget {
  HomeScreen(UserBean bean) {
    userBean = bean;
  }

  @override
  _HomeScreenState createState() => _HomeScreenState();
}

class _HomeScreenState extends State<HomeScreen> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        backgroundColor: Colors.white,
        elevation: 0,
        title: Text(
          'Invite Friends',
          style: TextStyle(color: Colors.black),
        ),
        leading: IconButton(
            icon: Icon(
              Icons.arrow_back,
              color: Colors.black,
            ),
            onPressed: () {
              Navigator.pop(context);
            }),
      ),
      backgroundColor: Colors.white,
      body: Material(
        color: Colors.white,
        child: Stack(
          children: [
            Container(
              padding: EdgeInsets.only(left: 20, right: 20),
              child: SingleChildScrollView(
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.start,
                  children: [
                    AddSizeBox(10, 0),
                    Text(
                      //'Get funds added to your wallet by inviting your email or phone book to download Petro.',
                      'Get funds added to your wallet by inviting your email or phonebook friends to download ' +
                          StringUtils.YOUR_APP_NAME +
                          ".",
                      style: TextStyle(
                        color: Colors.black,
                        fontWeight: FontWeight.normal,
                        fontSize: 16,
                      ),
                    ),
                    AddSizeBox(30, 0),
                    Image.asset(
                      StringUtils.IC_LOGO,
                      width: 50,
                      height: 50,
                    ),
                    AddSizeBox(30, 0),
                    Text(
                   // 'You friends will receive a customized email and sms including your identity.\nWe pay for the sms, you earn the credit.',
                      'Your friends will receive a customized email and SMS including your identity.\nWe pay for the SMS, you earn the credit.',
                      style: TextStyle(
                        color: Colors.black,
                        fontWeight: FontWeight.normal,
                        fontSize: 16,
                      ),
                    ),
                    Align(
                      alignment: Alignment.centerLeft,
                      child: InkWell(
                        onTap: () {
                          CommonUtils.openURL(StringUtils.LEARN_MORE_URL);
                        },
                        child: AddText(StringUtils.LEARN_MORE, Colors.blue,
                            16, FontWeight.normal, true),
                      ),
                    ),
                    AddSizeBox(20, 0),
                    /*InkWell(
                      onTap: () {
                        setState(() {
                          isLoading = true;
                        });
                        sendTestSms();
                      },
                      child: AddText(StringUtils.SAMPLE_SMS_INVITE, Colors.blue,
                          16, FontWeight.normal, true),
                    ),
                    InkWell(
                      onTap: () {
                        setState(() {
                          isLoading = true;
                        });
                        sendTestEmail();
                      },
                      child: AddText(StringUtils.SAMPLE_EMAIL_INVITE,
                          Colors.blue, 16, FontWeight.normal, true),
                    ),
                    AddSizeBox(30, 0),
                    AddText(StringUtils.TERMS_AND_CONDITION, Colors.black, 16,
                        FontWeight.normal, false),
                    AddSizeBox(30, 0),*/
                    BottomButton(true),
                    BottomButton(false),
                    AddSizeBox(20, 0),
                    Text(
                      'Powered by Share Apps Advertising',
                      style: TextStyle(
                        color: Colors.black,
                        fontWeight: FontWeight.normal,
                        fontSize: 16,
                      ),
                    ),
                  ],
                ),
              ),
            ),
            isLoading ? addProgress() : Container(),
          ],
        ),
      ),
    );
  }

  Future<void> requestPermission(Permission permission) async {
    final status = await permission.request();
    if (status == PermissionStatus.granted) {
      selectContact();
    }
  }

  void selectContact() async {
    Navigator.pushReplacement(context,
        MaterialPageRoute(builder: (context) => ContactSelection(userBean)));
  }

  Widget BottomButton(bool isEmail) {
    return InkWell(
      onTap: () {
        isEmail
            ? Navigator.pushReplacement(
                context,
                MaterialPageRoute(
                    builder: (context) => EmailInvitationLoading()))
            : requestPermission(Permission.contacts);
      },
      child: Container(
        width: double.infinity,
        decoration: BoxDecoration(
            color: isEmail ? Colors.grey : Colors.black,
            border: Border(
                left: BorderSide(color: Colors.black, width: 1),
                bottom: BorderSide(color: Colors.black, width: 1),
                right: BorderSide(color: Colors.black, width: 1),
                top: BorderSide(color: Colors.black, width: 1))),
        margin: isEmail
            ? EdgeInsets.only(top: 10, bottom: 10)
            : EdgeInsets.only(bottom: 10),
        child: Padding(
          padding: const EdgeInsets.all(15.0),
          child: AddText(
              isEmail
                  ? StringUtils.EMAIL_FRIENDS
                  : StringUtils.PHONE_BOOK_FRIENDS,
              Colors.white,
              18.0,
              FontWeight.bold,
              false),
        ),
      ),
    );
  }

  Future<void> sendTestSms() async {
    var body = json.encode({
      StringUtils.PHONE_NUMBER_PARAM: userBean.phone,
      StringUtils.TEMPLATE_ID: StringUtils.TEMPLATE_ID_VALUE,
      StringUtils.COUNTRY_ID: userBean.country_id,
    });
    var p = await CommonUtils.apiCall(StringUtils.API_TEST_SMS, body, context);
    setState(() {
      isLoading = false;
    });
    CommonUtils.showToast(p[StringUtils.MESSAGE], Colors.green);
  }

  Future<void> sendTestEmail() async {
    var body = json.encode({
      StringUtils.EMAIL_PARAM: userBean.email,
      StringUtils.TEMPLATE_ID: StringUtils.TEMPLATE_ID_VALUE
    });
    var p =
        await CommonUtils.apiCall(StringUtils.API_TEST_EMAIL, body, context);
    setState(() {
      isLoading = false;
    });
    CommonUtils.showToast(p[StringUtils.MESSAGE], Colors.green);
  }
}
