import 'dart:convert';
import 'dart:io';
import 'dart:ui';

import 'package:device_id/device_id.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter/widgets.dart';
import 'package:searchable_dropdown/searchable_dropdown.dart';
import 'package:share_apps/model/user_bean.dart';
import 'package:share_apps/utils/common_utils.dart';
import 'package:share_apps/utils/list_utils.dart';
import 'package:share_apps/utils/string_utils.dart';
import 'package:share_apps/widgets/widgets_importer.dart';
import 'package:shared_preferences/shared_preferences.dart';

import '../utils/string_utils.dart';
import 'app_registration_screen.dart';

final FocusNode _firstNameFocus = FocusNode();
final FocusNode _lastNameFocus = FocusNode();
final FocusNode _emailAddressFocus = FocusNode();
final FocusNode _phoneNumberFocus = FocusNode();
final _formKey = GlobalKey<FormState>();

TextEditingController firstNameController;
TextEditingController lastNameController;
TextEditingController emailController;
TextEditingController numberController;

UserBean _userBean;

class InvitationForm extends StatefulWidget {
  InvitationForm(UserBean bean) {
    _userBean = bean;
    firstNameController = new TextEditingController(text: _userBean.first_name);
    lastNameController = new TextEditingController(text: _userBean.last_name);
    emailController = new TextEditingController(text: _userBean.email);
    numberController = new TextEditingController(text: _userBean.phone);
  }

  @override
  _InvitationFormState createState() => _InvitationFormState();
}

String _deviceId;

class _InvitationFormState extends State<InvitationForm> {
  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    initDeviceId();
    for (int i = 0; i < ListUtil.language_list.length; i++) {
      languageItems.add(DropdownMenuItem(
        child: Text(ListUtil.language_list[i]),
        value: ListUtil.language_list[i],
      ));
    }

    for (int i = 0; i < ListUtil.country_list.length; i++) {
      countryItems.add(DropdownMenuItem(
        child: Text(ListUtil.country_list[i]),
        value: ListUtil.country_list[i],
      ));
    }
  }

  final List<DropdownMenuItem> languageItems = [], countryItems = [];

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      debugShowCheckedModeBanner: false,
      home: Scaffold(
        backgroundColor: Colors.white,
        body: SingleChildScrollView(
          child: Container(
            margin: EdgeInsets.all(20),
            color: Colors.white,
            child: Form(
              key: _formKey,
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  AddSizeBox(50, 0),
                  //------------------
                  AddText(StringUtils.FIRST_NAME, Colors.black, 15.0,
                      FontWeight.bold, false),
                  AddSizeBox(15, 0),
                  AddTextField(
                      context,
                      TextInputType.text,
                      TextInputAction.next,
                      StringUtils.FIRST_NAME,
                      _firstNameFocus,
                      _lastNameFocus,
                      firstNameController),
                  //------------------
                  AddSizeBox(15, 0),
                  AddText(StringUtils.LAST_NAME, Colors.black, 15.0,
                      FontWeight.bold, false),
                  AddSizeBox(15, 0),
                  AddTextField(
                      context,
                      TextInputType.text,
                      TextInputAction.next,
                      StringUtils.LAST_NAME,
                      _lastNameFocus,
                      _emailAddressFocus,
                      lastNameController),
                  //------------------
                  AddSizeBox(15, 0),
                  AddText(StringUtils.EMAIL, Colors.black, 15.0,
                      FontWeight.bold, false),
                  AddSizeBox(15, 0),
                  AddTextField(
                      context,
                      TextInputType.emailAddress,
                      TextInputAction.next,
                      StringUtils.EMAIL,
                      _emailAddressFocus,
                      _phoneNumberFocus,
                      emailController),
                  //------------------
                  AddSizeBox(15, 0),
                  AddText(StringUtils.COUNTRY, Colors.black, 15.0,
                      FontWeight.bold, false),
                  AddSizeBox(15, 0),
                  // SetLangaugeCountryData(true),
                  SearchableDropdown.single(
                    displayClearIcon: false,
                    items: countryItems,
                    value: _selectedCountry,
                    hint: "Select Country",
                    searchHint: "Select Country",
                    onChanged: (value) {
                      setState(() {
                        _selectedCountry = value;
                      });
                    },
                    isExpanded: true,
                  ),
                  //------------------
                  AddSizeBox(15, 0),
                  AddText(StringUtils.PHONE_NUMBER, Colors.black, 15.0,
                      FontWeight.bold, false),
                  AddSizeBox(15, 0),
                  AddTextField(
                      context,
                      TextInputType.number,
                      TextInputAction.done,
                      StringUtils.PHONE_NUMBER,
                      _phoneNumberFocus,
                      _phoneNumberFocus,
                      numberController),
                  //------------------
                  AddSizeBox(15, 0),
                  AddText(StringUtils.LANGUAGE, Colors.black, 15.0,
                      FontWeight.bold, false),
                  AddSizeBox(15, 0),
                  // SetLangaugeCountryData(false),
                  SearchableDropdown.single(
                    displayClearIcon: false,
                    items: languageItems,
                    value: _selectedLanguage,
                    hint: "Select Language",
                    searchHint: "Select Language",
                    onChanged: (value) {
                      setState(() {
                        _selectedLanguage = value;
                      });
                    },
                    isExpanded: true,
                  ),
                  //------------------
                  AddSizeBox(50, 0),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.center,
                    children: [BottomButton(true), BottomButton(false)],
                  ),
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }

  Widget BottomButton(bool isExit) {
    return Expanded(
      flex: 1,
      child: InkWell(
        onTap: () {
          if (isExit) {
            Navigator.pop(context);
          } else {
            if (_formKey.currentState.validate()) {
              if (_selectedCountry == '') {
                CommonUtils.showToast('Selected Country', Colors.red);
              } else if (numberController.text.length < 5) {
                CommonUtils.showToast(StringUtils.ERROR_NUMBER, Colors.red);
              } else if (_selectedLanguage == '') {
                CommonUtils.showToast('Selected Language', Colors.red);
              } else {
                UserBean bean = new UserBean(
                    firstNameController.text,
                    lastNameController.text,
                    emailController.text,
                    getNumber(),
                    (ListUtil.country_list.indexOf(_selectedCountry))
                        .toString(),
                    _selectedLanguage,
                    _deviceId);
                saveUserData(StringUtils.USER_DATA, bean);
              }
            }
          }
        },
        child: Container(
          margin: EdgeInsets.all(5),
          color: isExit ? Colors.amberAccent : Colors.green,
          child: Padding(
            padding: const EdgeInsets.all(15.0),
            child: AddText(isExit ? StringUtils.EXIT : StringUtils.PROCEED,
                Colors.white, 18.0, FontWeight.bold, false),
          ),
        ),
      ),
    );
  }

  var _selectedLanguage =
      (_userBean.language != null && _userBean.language.length > 0)
          ? _userBean.language
          : "";
  var _selectedCountry =
      (_userBean.country_id != null && _userBean.country_id.length > 0)
          ? ListUtil.country_list[int.parse(_userBean.country_id)]
          : "";

  Widget SetLangaugeCountryData(bool isCountry) {
    return DropdownButton<String>(
      isExpanded: true,
      value: isCountry ? _selectedCountry : _selectedLanguage,
      elevation: 16,
      style: TextStyle(color: Colors.black),
      underline: Container(
        height: 2,
        color: Colors.black,
      ),
      onChanged: (String newValue) {
        setState(() {
          if (isCountry) {
            _selectedCountry = newValue;
          } else
            _selectedLanguage = newValue;
        });
      },
      items: (isCountry ? ListUtil.country_list : ListUtil.language_list)
          .map((String value) {
        return DropdownMenuItem<String>(
          value: value,
          child: Text(value),
        );
      }).toList(),
    );
  }

  Future<void> initDeviceId() async {
    _deviceId = await DeviceId.getID;
    if (!mounted) return;
  }

  Future<void> openNextScreen(UserBean bean) async {
    try {
      final result = await InternetAddress.lookup('google.com');
      if (result.isNotEmpty && result[0].rawAddress.isNotEmpty) {
        Route route = MaterialPageRoute(
            builder: (context) => AppRegistrationScreen(bean));
        Navigator.pushReplacement(context, route);
      }
    } on SocketException catch (_) {
      CommonUtils.showToast(StringUtils.CHECK_NETWORK, Colors.red);
    }
  }

  void saveUserData(String key, UserBean bean) async {
    final prefs = await SharedPreferences.getInstance();
    prefs.setString(key, jsonEncode(bean.toJson()));
    openNextScreen(bean);
  }

  String getNumber() {
    String number = numberController.text;
    if (!number.contains("+")) {
      number = ListUtil.country_code_list[
              (ListUtil.country_list.indexOf(_selectedCountry))] +
          number;
    }
    return number;
  }
}
